@@ -72,7 +72,7 @@ def objects():
     #~ yield projectType(u"EiEi")
     #~ yield projectType(u"Aufenthaltsgenehmigung")
     
-    studyType = Instantiator('jobs.StudyType').build
+    studyType = Instantiator('isip.StudyType').build
     #~ yield studyType(u"Schule")
     #~ yield studyType(u"Sonderschule")
     #~ yield studyType(u"Ausbildung")
@@ -292,4 +292,4 @@ The eventual noble condition of this person. Imported from TIM.
     yield I(t,'language',u"""\
     Die Sprache, in der Dokumente ausgestellt werden sollen.
 """)
-    
\ No newline at end of file
+    
