@@ -38,6 +38,8 @@ from django.core.exceptions import ValidationError
 from django.conf import settings
 
 from django.db.utils import DatabaseError
+from django.db import IntegrityError
+
 # OperationalError
 from django.utils import simplejson
 #~ from django.contrib.auth import models as auth
@@ -61,6 +63,9 @@ from lino.utils.daemoncommand import DaemonCommand
 
 from lino.utils.ssin import is_valid_ssin
 
+
+IGNORABLE_ERRORS = (ValidationError,IntegrityError)
+
 #~ from lino_welfare.modlib.pcsw import models as pcsw
 #~ from lino_welfare.modlib.pcsw.management.commands.initdb_tim import ADR_id
 
@@ -119,6 +124,7 @@ def isolang(x):
     if x == 'D' : return 'de'
     if x == 'F' : return 'fr'
     if x == 'N' : return 'nl'
+    return 'de' # silently tolerate invalid values
       
 def ADR_id(cIdAdr):
     assert len(cIdAdr) == 3
@@ -622,6 +628,7 @@ class PAR(Controller):
                             #~ pass
                         
         elif obj.__class__ is Company:
+            #~ obj.prefix = data.get('ALLO','')
             mapper.update(prefix='ALLO')
             mapper.update(vat_id='NOTVA')
             mapper.update(name='FIRME')
@@ -638,7 +645,7 @@ class PAR(Controller):
         pk = kw['id']
         if not pk: return None
         pk = int(pk)
-        if pk == 0: return None
+        if pk == 0: return None # mysql: "The database backend does not accept 0 as a value for AutoField."
         #~ possible_models = [Client, Person, Company, Household, Partner]
         #~ model = PAR_model(kw['data'])
         #~ delete_child
@@ -698,7 +705,11 @@ class PAR(Controller):
             newobj = obj = obj.person_ptr
             old_class = Person
             
-        if new_class is not old_class and not issubclass(new_class,old_class):
+        if old_class is new_class:
+            return
+            
+        #~ if new_class is not old_class and not issubclass(new_class,old_class):
+        if  not issubclass(new_class,old_class):
             dd.pre_remove_child.send(sender=obj,request=REQUEST,child=old_class)
             mti.delete_child(obj,old_class)
             newobj = obj = partner
@@ -924,7 +935,7 @@ def watch(data_dir):
                 "Exception '%r' while processing changelog line:\n%s", 
                 e,ln)
             # for ValidationError we don't want a full traceback with mail to the admins.
-            if not isinstance(e,ValidationError):
+            if not isinstance(e,IGNORABLE_ERRORS):
                 dblogger.exception(e)
             #~ raise
     fd_watching.close()
