@@ -144,6 +144,23 @@ For example 1 means a monthly amount, 12 a yearly amount."""),
         #~ return super(DebtsUserTable,self).get_permission(action,user,obj)
         
 
+from django.db import transaction
+
+@transaction.commit_on_success
+def bulk_create_with_manual_ids(model,obj_list):
+    """
+    Originally copied from http://stackoverflow.com/a/13143062/407239
+    
+    """
+    last = model.objects.all().aggregate(models.Max('id'))['id__max']
+    if last is None:
+        id_start = 1
+    else:
+        id_start = last + 1
+    for i,obj in enumerate(obj_list): obj.id = id_start + i
+    #~ print 20130508, [dd.obj2str(o) for o in obj_list]
+    return model.objects.bulk_create(obj_list)
+    
 
 
 
@@ -317,17 +334,7 @@ The total monthly amount available for debts distribution."""))
             rv += amount
         return rv
       
-    #~ @dd.displayfield(_("Summary"))
-    #~ def summary(self,rr):
-        #~ return 'Not <b>yet</b> written.'
-      
-    #~ def full_clean(self,*args,**kw):
-        #~ super(Budget,self).full_clean(*args,**kw)
         
-    #~ def save(self,*args,**kw):
-        #~ super(Budget,self).save(*args,**kw)
-        
-    #~ def _changed(self,ar):
     def after_ui_save(self,ar,**kw):
         """
         Called from `extjs3.ext_ui.ExtUI.form2obj_and_save`
@@ -337,31 +344,48 @@ The total monthly amount available for debts distribution."""))
         return kw
         
     def fill_defaults(self,ar=None):
+        """
+        If the budget is empty, fill it with default entries 
+        by copying the master_budget.
+        """
         #~ if self.closed:
         if not self.partner or self.build_time:
             return
         if self.entry_set.all().count() > 0:
             return
         self.save()
-        flt = models.Q(required_for_household=True)
-        flt = flt | models.Q(required_for_person=True)
-        #~ required =  # .values_list('id',flat=True)
-        #~ missing = set(required)
-        seqno = 0
-        #~ for e in Entry.objects.filter(budget=self):
-            #~ missing.discard(e.account.pk)
-            #~ seqno = max(seqno,e.seqno)
-        for acc in accounts.Account.objects.filter(flt).order_by('ref'):
-            #~ if pk in missing:
-            seqno += 1
-            e = Entry(account=acc,budget=self,seqno=seqno)
-            e.account_changed(ar)
-            e.periods = e.account.periods
-            if e.account.default_amount:
-                e.amount = e.account.default_amount
-            e.full_clean()
-            e.save()
-            #~ print e
+        entries = []
+        master_budget = settings.SITE.site_config.master_budget
+        if master_budget is None:
+            flt = models.Q(required_for_household=True)
+            flt = flt | models.Q(required_for_person=True)
+            seqno = 0
+            for acc in accounts.Account.objects.filter(flt).order_by('ref'):
+                seqno += 1
+                e = Entry(account=acc,budget=self,seqno=seqno,account_type=acc.type)
+                e.account_changed(ar)
+                #~ e.periods = e.account.periods
+                if e.account.default_amount:
+                    e.amount = e.account.default_amount
+                entries.append(e)
+        else:
+            seqno = 0
+            for me in master_budget.entry_set.order_by('seqno').select_related():
+                seqno += 1
+                e = Entry(account=me.account,budget=self,
+                    account_type=me.account_type,
+                    seqno=me.seqno,periods=me.periods,
+                    amount=me.amount)
+                e.account_changed(ar)
+                entries.append(e)
+        if True:
+            bulk_create_with_manual_ids(Entry,entries)
+        else:
+            for e in entries:
+                e.full_clean()
+                e.save()
+            
+            
         if self.actor_set.all().count() == 0:
             household = self.partner.get_mti_child('household')
             if household:
@@ -409,6 +433,7 @@ The total monthly amount available for debts distribution."""))
         #~ render(self.dist_by_budget(ar))
         render(ResultByBudget.request(self))
         render(DebtsByBudget.request(self))
+        render(BailiffDebtsByBudget.request(self))
         render(DistByBudget.request(self))
         return E.div(*chunks)
         
@@ -450,6 +475,7 @@ class BudgetDetail(dd.FormLayout):
     summary1 = """
     ResultByBudget
     DebtsByBudget
+    BailiffDebtsByBudget
     """
     summary2 = """
     conclusion:30x5 
@@ -476,7 +502,7 @@ class Budgets(dd.Table):
     but is directly used by :menuselection:`Explorer --> Debts -->Budgets`.
     """
     model = Budget
-    required = dict(user_groups = ['debts'])
+    required = dd.required(user_groups='debts',user_level='manager')
     #~ required_user_groups = ['debts']
     detail_layout = BudgetDetail()
     insert_layout = dd.FormLayout("""
@@ -490,11 +516,12 @@ class Budgets(dd.Table):
 
 
 class MyBudgets(Budgets,mixins.ByUser):
-    pass
+    required = dd.required(user_groups='debts')
     
 class BudgetsByPartner(Budgets):
     master_key = 'partner'
     label = _("Is partner of these budgets:")
+    required = dd.required(user_groups='debts')
     
 
     
@@ -575,7 +602,8 @@ class Actor(ActorBase,SequencedBudgetComponent):
         
     
 class Actors(dd.Table):
-    required = dict(user_groups = ['debts'])
+    required = dd.required(user_groups='debts',user_level='manager')
+    
     #~ required_user_groups = ['debts']
     model = Actor
     column_names = "budget seqno partner header remark *"
@@ -584,6 +612,7 @@ class ActorsByBudget(Actors):
     """
     The table used to edit Actors in a Budget's detail.
     """
+    required = dd.required(user_groups='debts')
     master_key = 'budget'
     column_names = "seqno partner header remark *"
     auto_fit_column_widths = True
@@ -591,10 +620,13 @@ class ActorsByBudget(Actors):
     
     
 class ActorsByPartner(Actors):
+    required = dd.required(user_groups='debts')
     master_key = 'partner'
     label = _("Is actor in these budgets:")
     editable = False
     
+    
+
 
 
 class Entry(SequencedBudgetComponent):
@@ -652,6 +684,11 @@ Eventueller Betrag monatlicher Rückzahlungen, über deren Zahlung nicht verhand
 Wenn hier ein Betrag steht, darf "Verteilen" nicht angekreuzt sein.
     """)
     
+    bailiff = models.ForeignKey('contacts.Company',
+        verbose_name=_("Bailiff"),
+        related_name='bailiff_debts_set',
+        null=True,blank=True)
+    
     #~ duplicated_fields = """
     #~ account_type account partner actor distribute 
     #~ circa todo remark description periods monthly_rate
@@ -662,6 +699,16 @@ Wenn hier ein Betrag steht, darf "Verteilen" nicht angekreuzt sein.
         #~ print '20120918 account_choices', account_type
         return accounts.Account.objects.filter(type=account_type)
         
+    @dd.chooser()
+    def bailiff_choices(self):
+        qs = contacts.Companies.request().data_iterator
+        bt = settings.SITE.site_config.debts_bailiff_type
+        if bt is not None:
+            qs = qs.filter(client_contact_type=bt)
+        return qs
+        
+        
+        
     #~ @chooser(simple_values=True)
     #~ def amount_choices(cls,account):
         #~ return [decimal.Decimal("0"),decimal.Decimal("2.34"),decimal.Decimal("12.34")]
@@ -701,6 +748,9 @@ Wenn hier ein Betrag steht, darf "Verteilen" nicht angekreuzt sein.
             raise ValidationError(
               #~ _("Cannot set both 'Distribute' and 'Monthly rate'"))
               _("Cannot set 'Distribute' when 'Monthly rate' is %r") % self.monthly_rate)
+        #~ self.account_type = self.account.type
+        #~ if not self.account_type:
+            #~ raise ValidationError(_("Budget entry #%d has no account_type") % obj2unicode(self))
         super(Entry,self).full_clean(*args,**kw)
       
     def save(self,*args,**kw):
@@ -730,13 +780,14 @@ Wenn hier ein Betrag steht, darf "Verteilen" nicht angekreuzt sein.
         get duplicated *before* related Entries. 
         The order of `fklist` in `_lino_ddh` 
         """
-        if master is not None and self.actor and self.actor.budget != master: 
+        if master is not None and self.actor is not None and self.actor.budget != master: 
             self.actor = master.actor_set.get(seqno=self.actor.seqno)
         super(Entry,self).on_duplicate(ar,master)
             
 class Entries(dd.Table):
     model = Entry
-    required = dict(user_groups = ['debts'],user_level='manager')
+    required = dd.required(user_groups='debts',user_level='admin')
+    
     #~ required_user_groups = ['debts']
     #~ required_user_level = UserLevels.manager
 
@@ -744,7 +795,7 @@ class Entries(dd.Table):
 class EntriesByType(Entries):
     _account_type = None
     #~ required_user_level = None
-    required=dict(user_groups = ['debts'])
+    required = dd.required(user_groups='debts')
   
     @classmethod
     def class_init(self):
@@ -768,7 +819,7 @@ class EntriesByBudget(Entries):
     column_names = "account description amount actor:10 periods:10 remark move_buttons seqno todo"
     hidden_columns = "seqno"
     auto_fit_column_widths = True
-    required = dict(user_groups = ['debts'])
+    required = dd.required(user_groups='debts')
     #~ required_user_level = None
     order_by = ['seqno']
 
@@ -783,7 +834,7 @@ class IncomesByBudget(EntriesByBudget,EntriesByType):
 class LiabilitiesByBudget(EntriesByBudget,EntriesByType):
     "Liabilities By Budget"
     _account_type = AccountTypes.liabilities
-    column_names = "account partner remark amount actor:10 distribute monthly_rate todo seqno"
+    column_names = "account partner remark amount actor:10 bailiff distribute monthly_rate todo seqno"
     
 class AssetsByBudget(EntriesByBudget,EntriesByType):
     _account_type = AccountTypes.assets
@@ -855,6 +906,7 @@ class PrintEntriesByBudget(dd.VirtualTable):
             self.description = e.description
             self.periods = e.periods
             self.partner = e.partner
+            self.bailiff = e.bailiff
             self.remarks = []
             self.account = e.account
             self.monthly_rate = e.monthly_rate
@@ -866,6 +918,7 @@ class PrintEntriesByBudget(dd.VirtualTable):
             
         def matches(self,e):
             if e.partner != self.partner: return False
+            if e.bailiff != self.bailiff: return False
             if e.account != self.account: return False
             if e.monthly_rate != self.monthly_rate: return False
             if e.periods != self.periods: return False
@@ -930,11 +983,14 @@ class PrintEntriesByBudget(dd.VirtualTable):
             #~ return "%s (%s / %s)" % (obj.description,obj.total,obj.periods)
         #~ return obj.description
         
-    #~ @dd.displayfield(_("Partner"))
     @dd.virtualfield(models.ForeignKey('contacts.Partner'))
     def partner(self,obj,ar):
         return obj.partner
         
+    @dd.virtualfield(models.ForeignKey('contacts.Company',verbose_name=_("Bailiff")))
+    def bailiff(self,obj,ar):
+        return obj.bailiff
+        
     # TODO: generate them dynamically:
     
     @dd.virtualfield(dd.PriceField(_("Amount")))
@@ -976,7 +1032,7 @@ class PrintLiabilitiesByBudget(PrintEntriesByBudget):
     help_text = _("""Print version of :ref:`welfare.debts.LiabilitiesByBudget`.""")
     _account_type = AccountTypes.liabilities
     #~ column_names = "partner description total monthly_rate todo"
-    column_names = "partner:20 description:20 monthly_rate dynamic_amounts"
+    column_names = "partner:20 description:20 bailiff monthly_rate dynamic_amounts"
     
 class PrintAssetsByBudget(PrintEntriesByBudget):
     """Print version of :class:`AssetsByBudget` table."""
@@ -1036,9 +1092,9 @@ class SummaryTable(dd.VirtualTable):
   
 #~ class BudgetSummary(SummaryTable):
 class ResultByBudget(SummaryTable):
-    help_text = _("""Shows the "Incomes & Expenses" for this budget.""")
+    help_text = _("""Shows the Incomes & Expenses for this budget.""")
     label = _("Incomes & Expenses")
-    required=dict(user_groups = ['debts'])
+    required = dd.required(user_groups='debts')
     master = Budget
     
     @classmethod
@@ -1084,8 +1140,9 @@ class ResultByBudget(SummaryTable):
         
 class DebtsByBudget(SummaryTable):
     label = _("Debts")
-    required=dict(user_groups = ['debts'])
+    required = dd.required(user_groups='debts')
     master = Budget
+    bailiff_isnull = True
     
     @classmethod
     def get_summary_numbers(self,ar):
@@ -1095,12 +1152,17 @@ class DebtsByBudget(SummaryTable):
         for grp in budget.account_groups('L'):
             for acc in grp.account_set.all():
                 yield [_("%s (distributable)") % dd.babelattr(acc,'name'), 
-                    budget.sum('amount',account=acc,distribute=True)]
+                    budget.sum('amount',account=acc,distribute=True,
+                    bailiff__isnull=self.bailiff_isnull)]
                 yield [dd.babelattr(acc,'name'), 
-                    budget.sum('amount',account=acc,distribute=False)]
+                    budget.sum('amount',account=acc,distribute=False,
+                        bailiff__isnull=self.bailiff_isnull)]
         #~ "Total Kredite / Schulden"
     
         
+class BailiffDebtsByBudget(DebtsByBudget):
+    label = _("Bailiff Debts")
+    bailiff_isnull = False
     
 #~ class DistByBudget(LiabilitiesByBudget):
 class DistByBudget(EntriesByBudget):
@@ -1164,7 +1226,7 @@ proportionally distributing the `Distributable amount` among the debtors.
     def description(self,obj,ar):
         desc = obj.description
         if obj.remark:
-            desc += ' (%s)' % obj.remarks
+            desc += ' (%s)' % obj.remark
         return desc
             #~ return "%s (%s / %s)" % (obj.description,obj.total,obj.periods)
         #~ return obj.description
@@ -1207,10 +1269,13 @@ def unused_setup_my_menu(site,ui,profile,m):
     m.add_action(MyBudgets)
   
 def setup_config_menu(site,ui,profile,m): 
-    pass
+    m  = m.add_menu("debts",MODULE_LABEL)
+    if site.site_config.master_budget:
+        fld = site.modules.ui.SiteConfig._meta.get_field('master_budget')
+        m.add_instance_action(site.site_config.master_budget,
+            label=unicode(fld.verbose_name))
     #~ if user.profile.debts_level < UserLevels.manager: 
         #~ return
-    #~ m  = m.add_menu("debts",MODULE_LABEL)
     #~ m.add_action(Accounts)
     #~ m.add_action(accounts.Groups)
     #~ m.add_action(DebtTypes)
@@ -1252,3 +1317,20 @@ def customize_accounts():
 
 customize_accounts()
 
+
+dd.inject_field('ui.SiteConfig',
+    'debts_bailiff_type',
+    models.ForeignKey("pcsw.ClientContactType",
+        blank=True,null=True,
+        verbose_name=_("Bailiff"),
+        related_name='bailiff_type_sites',
+        help_text=_("Client contact type for Bailiff.")))
+    
+dd.inject_field('ui.SiteConfig',
+    'master_budget',
+    models.ForeignKey("debts.Budget",
+        blank=True,null=True,
+        verbose_name=_("Master budget"),
+        related_name='master_budget_sites',
+        help_text=_("The budget whose content is to be copied into new budgets.")))
+    
